/*
 * This macro allows you to use a 'C' function to handle a 68HC16 interrupt.
 *
 * The only parameter is the DECIMAL interrupt vector number.
 *
 * The macro MUST be placed IMMEDIATELY preceeding the definition of the
 * function which is to be the interrupt handler. Example:
 *
 * 		INTERRUPT(17) level_1_int_handler()
 * 		{
 *			/* ... Function code to level 1 external interrupt ... */
 *		}
 *
 * This file **REQUIRES** the extended pre-processor (MCP).
 * (CC16 ... -P, or "Preprocess" step enabled in DDSIDE)
 *
 * Copyright 1991-2005 Dave Dunfield
 * All rights reserved.
 */
#define	_SP_				/* Null separator */
#define	INTERRUPT(vec) asm {\
$SE:0						/* Insure output in code segment */\
_/**/vec	/* This label will be the address of the "prefix" stub */\
		ORG		vec*2		/* Position to interrupt vector */\
		FDB		_/**/vec	/* Enter the label address */\
		ORG		_/**/vec	/* Position back to original PC */\
		PSHM	D,E,X,Y,Z,K	/* Save processor registers */\
		TSKB				/* Assume stack is in C memory bank */\
		TBEK				/* Set active memory bank */\
		TBXK				/* Set 'X' active memory bank */\
		TBYK				/* Set 'Y' active memory bank */\
		TBZK				/* Set 'Z' active memory bank */\
		LDD		_SP_?temp	/* Get temp location */\
		PSHM	D			/* Save that too */\
		BSR		_SP_*+12	/* Execute C handler */\
		PULM	D			/* Get ?temp back */\
		STD		_SP_?temp	/* Restore */\
		PULM	D,E,X,Y,Z,K	/* Restore processor registers */\
		RTI					/* Back from interrupt */\
}
#undef _SP_
