/*
 * 68HC16 internal register definitions for DDS MICRO-C/16
 *
 * Since these registers are normally not located within the MICRO-C
 * data page, you cannot access these directly as variables. The
 * registers may be read with: peek[w](page, NAME) and written
 * with: poke[w](page, NAME, data);
 *
 * Due to the large number of definitions in this file, the external
 * pre-processor (MCP) must be used. If you would like to use the
 * internal pre-processor, or speed up processing, you may wish to
 * delete the definitions for those registers that you do not plan
 * to use.
 *
 * This file **REQUIRES** the extended pre-processor (MCP).
 * (CC16 ... -P, or "Preprocess" step enabled in DDSIDE)
 *
 * Copyright 1994-2005 Dave Dunfield
 * All rights reserved.
 */
#define SIMCR	0xFA00	/* SIM module configuration register */
#define SIMTR	0xFA02	/* System integration test register */
#define SYNCR	0xFA04	/* clock synthesizer control register */
#define RSR		0xFA07	/* reset status register */
#define SIMTRE	0xFA08	/* System integration test register (E clock) */
#define PORTE0	0xFA11	/* port E data register (same data as PORTE1) */
#define PORTE1	0xFA13	/* port E data register (same data as PORTE0) */
#define DDRE	0xFA15	/* port E data direction register */
#define PEPAR	0xFA17	/* port E pin assignment register */
#define PORTF0	0xFA19	/* port F data register (same data as PORTF1) */
#define PORTF1	0xFA1B	/* port F data register (same data as PORTF0) */
#define DDRF	0xFA1D	/* port F data direction register */
#define PFPAR	0xFA1F	/* port F pin assignment register */
#define SYPCR	0xFA21	/* System protection control register */
#define PICR	0xFA22	/* periodic interrupt control register */
#define PITR	0xFA24	/* periodic interrupt timing register */
#define SWSR	0xFA27	/* software service register */
#define TSTMSRA	0xFA30	/* master shift register A */
#define TSTMSRB	0xFA32	/* master shift register B */
#define TSTSC	0xFA34	/* test module shift count */
#define TSTRC	0xFA36	/* test module repetition count */
#define CREG	0xFA38	/* test submodule control register */
#define DREG	0xFA3A	/* distributed register */
#define CSPDR	0xFA41	/* port C data register */
#define CSPAR0	0xFA44	/* Chip-select pin assignment register 0 */
#define CSPAR1	0xFA46	/* Chip-select pin assignment register 1 */
#define CSBARBT	0xFA48	/* Chip-select boot base address register */
#define CSORBT	0xFA4A	/* Chip-select boot option register */
#define CSBAR0	0xFA4C	/* Chip-select 0 base address register */
#define CSOR0	0xFA4E	/* CHIP SELECT 0 option register */
#define CSBAR1	0xFA50	/* Chip-select 1 base address register */
#define CSOR1	0xFA52	/* Chip-select 1 option register */
#define CSBAR2	0xFA54	/* Chip-select 2 base address register */
#define CSOR2	0xFA56	/* Chip-select 2 option register */
#define CSBAR3	0xFA58	/* Chip-select 3 base address register */
#define CSOR3	0xFA5A	/* Chip-select 3 option register */
#define CSBAR4	0xFA5C	/* Chip-select 4 base address register */
#define CSOR4	0xFA5E	/* Chip-select 4 option register */
#define CSBAR5	0xFA60	/* Chip-select 5 base address register */
#define CSOR5	0xFA62	/* Chip-select 5 option register */
#define CSBAR6	0xFA64	/* Chip-select 6 base address register */
#define CSOR6	0xFA66	/* Chip-select 6 option register */
#define CSBAR7	0xFA68	/* Chip-select 7 base address register */
#define CSOR7	0xFA6A	/* Chip-select 7 option register */
#define CSBAR8	0xFA6C	/* Chip-select 8 base address register */
#define CSOR8	0xFA6E	/* Chip-select 8 option register */
#define CSBAR9	0xFA70	/* Chip-select 9 base address register */
#define CSOR9	0xFA72	/* Chip-select 9 option register */
#define CSBAR10	0xFA74	/* Chip-select 10 base address register */
#define CSOR10	0xFA76	/* Chip-select 10 option register */
/* SRAM module registerS */
#define RAMMCR	0xFB00	/* RAM module configuration register */
#define RAMTST	0xFB02	/* RAM test register */
#define RAMBAH	0xFB04	/* RAM base address HIGH register */
#define RAMBAL	0xFB06	/* RAM base address LOW register */
/* QSM ADDRESS MAP */
#define QSMCR	0xFC00	/* QSM module configuration register */
#define QTEST	0xFC02	/* QSM test register */
#define QILR	0xFC04	/* QSM interrupt levels register */
#define QIVR	0xFC05	/* QSM interrupt vector register */
#define SCCR0	0xFC08	/* SCI control register 0 */
#define SCCR1	0xFC0A	/* SCI control register 1 */
#define SCSR	0xFC0C	/* SCI status register */
#define SCDR	0xFC0E	/* SCI data register (FULL WORD) */
#define QPDR	0xFC15	/* QSM port data register */
#define QPAR	0xFC16	/* QSM pin assignment register */
#define QDDR	0xFC17	/* QSM data direction register */
#define SPCR0	0xFC18	/* QSPI control register 0 */
#define SPCR1	0xFC1A	/* QSPI control register 1 */
#define SPCR2	0xFC1C	/* QSPI control register 2 */
#define SPCR3	0xFC1E	/* QSPI control register 3 */
#define SPSR	0xFC1F	/* QSPI status register */
#define RR0		0xFD00	/* SPI REC.RAM 0 */
#define RR1		0xFD02	/* SPI REC.RAM 1 */
#define RR2		0xFD04	/* SPI REC.RAM 2 */
#define RR3		0xFD06	/* SPI REC.RAM 3 */
#define RR4		0xFD08	/* SPI REC.RAM 4 */
#define RR5		0xFD0A	/* SPI REC.RAM 5 */
#define RR6		0xFD0C	/* SPI REC.RAM 6 */
#define RR7		0xFD0E	/* SPI REC.RAM 7 */
#define RR8		0xFD00	/* SPI REC.RAM 8 */
#define RR9		0xFD02	/* SPI REC.RAM 9 */
#define RRA		0xFD04	/* SPI REC.RAM A */
#define RRB		0xFD06	/* SPI REC.RAM B */
#define RRC		0xFD08	/* SPI REC.RAM C */
#define RRD		0xFD0A	/* SPI REC.RAM D */
#define RRE		0xFD0C	/* SPI REC.RAM E */
#define RRF		0xFD0E	/* SPI REC.RAM F */
#define TR0		0xFD20	/* SPI TXD.RAM 0 */
#define TR1		0xFD22	/* SPI TXD.RAM 1 */
#define TR2		0xFD24	/* SPI TXD.RAM 2 */
#define TR3		0xFD26	/* SPI TXD.RAM 3 */
#define TR4		0xFD28	/* SPI TXD.RAM 4 */
#define TR5		0xFD2A	/* SPI TXD.RAM 5 */
#define TR6		0xFD2C	/* SPI TXD.RAM 6 */
#define TR7		0xFD2E	/* SPI TXD.RAM 7 */
#define TR8		0xFD30	/* SPI TXD.RAM 8 */
#define TR9		0xFD32	/* SPI TXD.RAM 9 */
#define TRA		0xFD34	/* SPI TXD.RAM A */
#define TRB		0xFD36	/* SPI TXD.RAM B */
#define TRC		0xFD38	/* SPI TXD.RAM C */
#define TRD		0xFD3A	/* SPI TXD.RAM D */
#define TRE		0xFD3C	/* SPI TXD.RAM E */
#define TRF		0xFD3E	/* SPI TXD.RAM F */
#define CR0		0xFD40	/* SPI CMD.RAM 0 */
#define CR1		0xFD41	/* SPI CMD.RAM 1 */
#define CR2		0xFD42	/* SPI CMD.RAM 2 */
#define CR3		0xFD43	/* SPI CMD.RAM 3 */
#define CR4		0xFD44	/* SPI CMD.RAM 4 */
#define CR5		0xFD45	/* SPI CMD.RAM 5 */
#define CR6		0xFD46	/* SPI CMD.RAM 6 */
#define CR7		0xFD47	/* SPI CMD.RAM 7 */
#define CR8		0xFD48	/* SPI CMD.RAM 8 */
#define CR9		0xFD49	/* SPI CMD.RAM 9 */
#define CRA		0xFD4A	/* SPI CMD.RAM A */
#define CRB		0xFD4B	/* SPI CMD.RAM B */
#define CRC		0xFD4C	/* SPI CMD.RAM C */
#define CRD		0xFD4D	/* SPI CMD.RAM D */
#define CRE		0xFD4E	/* SPI CMD.RAM E */
#define CRF		0xFD4F	/* SPI CMD.RAM F */
/* GPT module registerS */
#define GPTMCR	0xF900	/* GPT module configuration register */
#define GPTMTR	0xF902	/* GPT module test register (reserved) */
#define ICR		0xF904	/* GPT interrupt configuration register */
#define PDDR	0xF906	/* parallel data direction register */
#define GPTPDR	0xF907	/* Parallel data register */
#define OC1M	0xF908	/* OC1 action mask register */
#define OC1D	0xF909	/* OC1 action data register */
#define TCNT	0xF90A	/* Timer counter register */
#define PACTL	0xF90C	/* Pulse accumulator control register */
#define PACNT	0xF90D	/* Pulse accumulator counter */
#define TIC1	0xF90E	/* Input capture register 1 */
#define TIC2	0xF910	/* Input capture register 2 */
#define TIC3	0xF912	/* Input capture register 3 */
#define TOC1	0xF914	/* Output compare register 1 */
#define TOC2	0xF916	/* Output compare register 2 */
#define TOC3	0xF918	/* Output compare register 3 */
#define TOC4	0xF91A	/* Output compare register 4 */
#define TI4O5	0xF91C	/* Input capture 4 OR output compare 5 */
#define TCTL1	0xF91E	/* Timer control register 1 */
#define TCTL2	0xF91F	/* Timer control register 2 */
#define TMSK1	0xF920	/* Timer interrupt mask register 1 */
#define TMSK2	0xF921	/* Timer interrupt mask register 2 */
#define TFLG1	0xF922	/* Timer interrupt flag register 1 */
#define TFLG2	0xF923	/* Timer interrupt flag register 2 */
#define CFORC	0xF924	/* Compare force register */
#define PWMC	0xF924	/* PWM control register */
#define PWMA	0xF926	/* PWM register A */
#define PWMB	0xF927	/* PWM register B */
#define PWMCNT	0xF928	/* PWM counter register */
#define PWMBUFA	0xF92A	/* PWM buffer register A */
#define PWMBUFB	0xF92B	/* PWM buffer register B */
#define PRESCL	0xF92C	/* GPT prescaler */
/* ADC module registerS */
#define ADCMCR	0xF700	/* ADC module configuration register */
#define ADtest	0xF702	/* ADC test register */
#define ADCPDR	0xF706	/* ADC port data register */
#define ADCTL0	0xF70A	/* A/D control register 0 */
#define ADCTL1	0xF70C	/* A/D control register 1 */
#define ADSTAT	0xF70E	/* ADC status register */
#define RJURR0	0xF710	/* Right justified unsigned result register 0 */
#define RJURR1	0xF712	/* Right justified unsigned result register 1 */
#define RJURR2	0xF714	/* Right justified unsigned result register 2 */
#define RJURR3	0xF716	/* Right justified unsigned result register 3 */
#define RJURR4	0xF718	/* Right justified unsigned result register 4 */
#define RJURR5	0xF71A	/* Right justified unsigned result register 5 */
#define RJURR6	0xF71C	/* Right justified unsigned result register 6 */
#define RJURR7	0xF71E	/* Right justified unsigned result register 7 */
#define LJSRR0	0xF720	/* Left justified signed result register 0 */
#define LJSRR1	0xF722	/* Left justified signed result register 1 */
#define LJSRR2	0xF724	/* Left justified signed result register 2 */
#define LJSRR3	0xF726	/* Left justified signed result register 3 */
#define LJSRR4	0xF728	/* Left justified signed result register 4 */
#define LJSRR5	0xF72A	/* Left justified signed result register 5 */
#define LJSRR6	0xF72C	/* Left justified signed result register 6 */
#define LJSRR7	0xF72E	/* Left justified signed result register 7 */
#define LJURR0	0xF730	/* Left justified unsigned result register 0 */
#define LJURR1	0xF732	/* Left justified unsigned result register 1 */
#define LJURR2	0xF734	/* Left justified unsigned result register 2 */
#define LJURR3	0xF736	/* Left justified unsigned result register 3 */
#define LJURR4	0xF738	/* Left justified unsigned result register 4 */
#define LJURR5	0xF73A	/* Left justified unsigned result register 5 */
#define LJURR6	0xF73C	/* Left justified unsigned result register 6 */
#define LJURR7	0xF73E	/* Left justified unsigned result register 7 */
