*
* Functions to perform basic arithmetic operations on arbitrarily
* large unsigned numbers. Supports: + - * / % <<1 >>1 == != < >
*
* To work on other than 32 bits, adjust the following constants:
?LSIZE	EQU	4		;4 bytes (32 bits)
$DD:Longreg	4
*
* Add two LONG numbers: longadd(num1, num2)
*
longadd	TSX			;Address parms
	LDY	4,X		;Get num2
	LDX	6,X		;Get num1
?bigadd	LDAB	#?LSIZE		;Get byte count
	CLRA			;No carry in
?1	LDAA	0,X		;Get byte from num1
	ADCA	0,Y		;Add num2
	STAA	0,X		;Resave dest
	AIX	#1		;Advance X
	AIY	#1		;Advance Y
	DECB			;Reduce count
	BNE	?1		;Do them all
	ROLB			;Get carry out
	CLRA			;Zero high
	RTS
*
* Shift LONG number right: longshr(num1)
*
longshr	TSX			;Address parm
	LDX	4,X		;Get num2
?bigshr	CLRA			;No carry in
	LDAB	#?LSIZE		;Get byte count
	ABX			;Adjust to end
?2	AIX	#-1		;Backup X
	ROR	0,X		;Shift one byte
	DECB			;Reduce count
	BNE	?2		;Do them all
	ROLB			;Get carry out
	CLRA			;Zero high
	RTS
*
* Test a LONG number for zero: longtst(num1)
*
longtst	TSX			;Address parms
	LDX	4,X		;Get num1
?bigtst	LDAA	#?LSIZE		;Get byte count
?3	LDAB	0,X		;Get byte
	BNE	?4		;Not zero - exit
	AIX	#1		;Advance X
	DECA			;Reduce count
	BNE	?3		;Exit
?4	RTS
*
* Multiply two LONG numbers: longmul(num1, num2)
*
longmul	PSHM	Z		;Save caller stack frame
	AIS	#-?LSIZE	;Get space on staclk
	TSZ			;Point to our stack frame
	TSX			;X = temp location
	LDY	?LSIZE+6,Z	;Get num2 pointer
	BSR	?bigcpy		;Copy the number
	BSR	?10		;Zero temp location
?5	LDX	?LSIZE+8,Z	;Point to num1
	BSR	?bigshr		;Do the shift
	TSTB			;Carry out?
	BEQ	?6		;No, leave it
	TSY			;Y points to num3
	LDX	#Longreg	;Point to temp
	BSR	?bigadd		;Do the addition
?6	LDX	?LSIZE+8,Z	;Point to num1
	BSR	?bigtst		;Test it
	BEQ	?7		;End, exit
	TSX			;Point to num3
	BSR	?bigshl		;Do the shift
	TSX			;Point to num3
	BSR	?bigtst		;Test it
	BNE	?5		;Keep going
?7	LDX	?LSIZE+8,Z	;Get num1 pointer
	AIS	#?LSIZE		;Clean stack
	PULM	Z		;Restore caller
	LDY	#Longreg	;Point to temp
	BRA	?bigcpy		;Copy & return
*
* Copy one LONG number to another: longcpy(num1, num2)
*
longcpy	TSX			;Address parms
	LDY	4,X		;Get num2
	LDX	6,X		;Get num1
?bigcpy	LDAB	#?LSIZE		;Get byte count
?8	LDAA	0,Y		;Get byte from num2
	STAA	0,X		;Copy to num1
	AIX	#1		;Advance num1
	AIY	#1		;Advance num2
	DECB			;Reduce count
	BNE	?8		;Do them all
	RTS
*
* Shift a LONG number left: longshl(num1)
*
longshl	TSX			;Address parm
	LDX	4,X		;Get num2
?bigshl	CLRA			;No carry in
?bigslc	LDAB	#?LSIZE		;Get byte count
?9	ROL	0,X		;Shift one byte
	AIX	#1		;Advance
	DECB			;Reduce count
	BNE	?9		;Do them all
	ROLB			;Get carry out
	CLRA			;Zero high
	RTS
*
* Zero the temporary location
*
?10	LDX	#Longreg	;Point to register
?11	LDAB	#?LSIZE		;Get byte count
?12	CLR	0,X		;Zero one byte
	AIX	#1		;Advance pointer
	DECB			;Reduce count
	BNE	?12		;Do them all
	RTS
*
* Divide two LONG numbers: longdiv(num1, num2)
*
longdiv	PSHM	Z		;Save callers stack frame
	TSZ			;Address out parms
	BSR	?10		;Zero temp location
	LDE	#?LSIZE*8+1	;Get bit count
?13	CLRA			;No carry in
?14	LDX	8,Z		;Point to num1
	BSR	?bigslc		;Shift it
	SUBE	#1		;Reduce count
	BEQ	?15		;End, exit
	LDX	#Longreg	;Point to temp
	RORB			;Set carry out
	BSR	?bigslc		;Do shift
	LDY	6,Z		;Point to num2
	LDX	#Longreg	;Point to temp
	BSR	?bigcmp		;Do compare
	TSTA			;Is it less
	BNE	?13		;Yes, carry zero
	LDY	6,Z		;Get num2
	LDX	#Longreg	;Point to temp
	BSR	?bigsub		;Do subtract
	ORP	#$0100		;Carry in 1
	BRA	?14		;And proceed
?15	PULM	Z
	RTS
*
* Compare two LONG numbers: longcmp(num1, num2)
*
longcmp	TSX			;Address parms
	LDY	4,X		;Get num2
	LDX	6,X		;Get num1
?bigcmp	LDAB	#?LSIZE		;Get byte count
	ABX			;Adjust num1 ptr
	ABY			;Adjust num2 ptr
?16	AIX	#-1		;Backup num1 ptr
	AIY	#-1		;Backup num2 ptr
	LDAA	0,X		;Get byte from source
	SUBA	0,Y		;Does it match?
	BLO	?17		;Its lower
	BHI	?18		;Its higher
	DECB			;Reduce count
	BNE	?16		;Test them all
	RTS
?17	LDD	#$FFFF		;Return -1
	RTS
?18	LDD	#1		;Return 1
	RTS
*
* Set a long number
*
longset	TSY			;Address parms
	LDX	6,Y		;Get address
	BSR	?11		;Zero it
	LDX	6,Y		;Get address back
	LDD	4,Y		;Get value
	STAB	0,X		;Write LOW
	STAA	1,X		;Write HIGH
	RTS
*
* Subtract two LONG numbers: longsub(num1, num2)
*
longsub	TSX			;Address parms
	LDY	4,X		;Get num2
	LDX	6,X		;Get num1
?bigsub	LDAB	#?LSIZE		;Get byte count
	CLRA			;No borrow in
?19	LDAA	0,X		;Get byte from num1
	SBCA	0,Y		;Subtract num2
	STAA	0,X		;Resave dest
	AIX	#1		;Advance X
	AIY	#1		;Advance Y
	DECB			;Reduce count
	BNE	?19		;Do them all
	ROLB			;Get carry out
	CLRA			;Zero high
	RTS
