*
* Allocate RAM in a segment: char *segalloc(seg, size)
*
segalloc PSHM	Z		; Save for stack address
	TSZ			; Address parms
	LDD	6,Z		; Get requested size
	ADDD	#1		; Insure large enough
	ANDB	#$FE		; Adjust to word boundary
	STD	6,Z		; Resave
	LDD	8,Z		; Get segment
	TBXK			; Set 'X' segment
	TBYK			; Set 'Y' segment
	LDY	#0		; Heap starts at zero
* Scan heap looking for free block
?1	LDD	0,Y		; Get block flag
	BEQ	?5		; End of heap, allocate here
	BMI	?2		; Allocated, skip it
* Free block - see if big enough
	LSLD			; Convert to size
	SUBD	6,Z		; Large enough?
	BHS	?3		; Yes, allocate here
* Block not large enough - skip to next
	LDD	0,Y		; Get size back
?2	LSLD			; Convert to binary size
	ADDD	#2		; Adjust for overhead
	ADY			; Skip to next
	BRA	?1		; And keep looking
* Block large enough - reallocate
?3	SUBD	#2		; Convert for overhead
	BHI	?4		; Ok to split
	LDD	0,Y		; Get original size back
	BRA	?7		; Not enough to split - leave alone
* Split block into two smaller blocks
?4	LDE	6,Z		; Get requested size
	TYX			; X = block address
	AEX			; X = next block address
	LSRD			; Convert to word count + free flag
	STD	2,X		; Write new size
	BRA	?6		; And proceed
* Allocate on the end of memory
?5	TYX			; X = copy
	XGDX			; D = address
	ADDD	#4		; Adjust for overhead
	BCS	?8		; Failure
	ADDD	6,Z		; Include size
	BCS	?8		; Failure
	XGDX			; X = next block
	CLRD			; Get zero marker
	STD	-2,X		; Set EOF marker
* Mark this block & its current size
?6	LDD	6,Z		; Get size
	LSRD			; Convert to word count
?7	ORAA	#$80		; Set allocated bit
	STD	0,Y		; Set marker
	TZKB			; Get extension
	TBXK			; Reset X
	TBYK			; Reset Y
	XGDY			; D = address
	ADDD	#2		; Report OK
	PULM	Z		; Restore stack frame
	RTS
* Unable to allocate block - report failure
?8	TZKB			; Get extension
	TBXK			; Reset X
	TBYK			; Reset Y
	CLRD			; Zero return
	PULM	Z		; Restore stack frame
	RTS
*
* Free a far segment: segfree(seg, size)
*
segfree	PSHM	Z		; Save stack frame
	TSZ			; Address parms
	LDD	6,Z		; Get address
	SUBD	#2		; Backup to real beginning
	STD	?temp		; Save for later
	LDD	8,Z		; Get segment
	TBXK			; Set 'X' segment
	TBYK			; Set 'Y' segment
	LDX	#0		; Heap begins at zero
?9	LDD	0,X		; Get allocation flag
	BEQ	?11		; End of list
	CPX	?temp		; Is this it?
	BEQ	?10		; Yes
* Skip to next block
	LSLD			; Convert to word count
	ADDD	#2		; Adjust for offset
	ADX			; Advance to next
	BRA	?9		; And proceed
* Mark this block as un-allocated
?10	ANDA	#$7F		; Clear allocated flag
	STD	0,X		; Resave flag
* Scan free list & combine free blocks
?11	LDX	#0		; Begin at zero again
?12	LDD	0,X		; Get allocation flag
	BEQ	?16		; End of list
	BMI	?14		; Allocated
* This block is free, check following blocks
	TXY			; Point to original
?13	LSLD			; Convert to byte offset
	ADDD	#2		; Adjust for overhead
	ADY			; Advance to next
	LDD	0,Y		; Get allocation flag
	BEQ	?15		; End of list - truncate
	BPL	?13		; Also free, keep going
* Resave this block size
	STX	?temp		; Save for later
	XGDY			; Y = block address
	SUBD	?temp		; D = total block size
	SUBD	#2		; Adjust for overhead
	LSRD			; Convert to word + free
	STD	0,X		; Resave count
* Advance to next block on list
?14	LSLD			; Conver to byte offset
	ADDD	#2		; Adjust for overhead
	ADX			; Advance to next
	BRA	?12		; And continue
* End of list - truncate at this entry
?15	STD	0,X		; Truncate list
?16	TZKB			; Get our segment
	TBXK			; Reset X
	TBYK			; Reset Y
	PULM	Z		; Restore stack frame
	RTS
