* Write string(x) to the SCI port
putstr	TSX			;Address stack
	LDX	4,X		;Get string pointer
?putstr	LDAB	0,X		;Get next byte
	BEQ	?putret		;End, exit
	BSR	?putch		;Write the string
	AIX	#1		;Advance to next
	BRA	?putstr		;And proceed
* Check for a character from the SCI port (with NL translation)
chkch	BSR	chkchr		;Test for character
	TSTA			;Character ready?
	BEQ	?2		;Proceed
	CLRD			;Indicate nothing
	RTS
* Check for a character from the SCI port (No translation)
chkchr	PSHM	K		;Save extension
	LDAB	#$0F		;Bank F for register access
	TBEK			;Set up K
	LDD	#$FFFF		;Assume invalid
	BRCLR	SCSR+1,#$40,?1	;No data available
	COMA			;Zero A
	LDAB	SCDR+1		;Get the data
?1	PULM	K		;Restore extension
	RTS
* Read a character from the SCI port (with NL translation)
getch	BSR	getchr		;Read a character
?2	CMPB	#$0D		;RETURN?
	BNE	?putret		;No, its OK
	LDAB	#$0A		;Convert to NEWLINE
	RTS
* Read a character from the SCI port (No translation)
getchr	PSHM	K		;Save extension
	LDAB	#$0F		;Bank F for register access
	TBEK			;Set up K
	BRCLR	SCSR+1,#$40,*	;Wait for character
	CLRA			;Zero high
	LDAB	SCDR+1		;Get the data
	PULM	K		;Restore extension
	RTS
* Write a character to the SCI port (with NL translation)
putch	TSX			;Address stack
	LDD	4,X		;Get character
?putch	BSR	?putchr		;Write it
	CMPB	#$0A		;Newline?
	BNE	?putret		;No, its OK
	LDAB	#$0D		;Follow with CR
	BRA	?putchr		;Write it
* Write a character to the SCI port (no translation)
putchr	TSX			;Address stack
	LDD	4,X		;Get character
?putchr	PSHM	D,E,K		;Save data & extension register
	CLRA			;Zero high
	TDE			;E = data
	LDAB	#$0F		;Bank F for register access
	TBEK			;Set up K
	BRCLR	SCSR,#$01,*	;Wait until xmitter is ready
	STE	SCDR		;transmit one ASCII character to the screen
	PULM	D,E,K		;Restore data & extension
?putret	RTS
* Read a string (with editing) from the console: getstr(buffer, length)
getstr	TSX			;Address stack
	LDY	6,X		;Get buffer ptr
	CLRE			;Zero count
?3	BSR	getch		;Get a character
	CMPB	#$7F		;Delete?
	BEQ	?4		;Yes, handle it
	CMPB	#$08		;Backspace?
	BEQ	?4		;Yes, handle it
	CMPB	#$0A		;Enter?
	BEQ	?5		;Yes, handle it
	CPE	4,X		;Within length
	BHS	?3		;No, ignore
	STAB	0,Y		;Write to buffer
	AIY	#1		;Advance to next
	ADDE	#1		;Advance count
	BSR	?putchr		;Echo character to console
	BRA	?3		;And proceed
?4	TSTE			;Any data in buffer?
	BEQ	?3		;No, ignore
	LDAB	#$08		;Backspace
	BSR	?putchr		;Echo
	LDAB	#' '		;Overwrite with space
	BSR	?putchr		;Echo
	LDAB	#$08		;Backspace
	BSR	?putchr		;Echo
	AIY	#-1		;Backup in buffer
	SUBE	#1		;Reduce length
	BRA	?3		;And proceed
?5	CLR	0,Y		;Zero end of buffer
	BSR	?putch		;New line on console
	XGDE			;Return buffer length
	RTS
